@@ -8,6 +8,9 @@ def fuzzy_match(needle, hay, flags=re.DOTALL, needle_length_window=0.2):
     Code adapted from: 
     https://stackoverflow.com/questions/17740833/checking-fuzzy-approximate-substring-existing-in-a-longer-string-in-python/31433394#31433394
     """
+    matched = re.search(needle, hay, flags=flags)
+    if matched is not None:
+        return matched
     try:
         needle_length  = len(needle.split())
         max_sim_val    = 0
@@ -19,13 +22,14 @@ def fuzzy_match(needle, hay, flags=re.DOTALL, needle_length_window=0.2):
                 max_sim_val = similarity
                 max_sim_string = hay_ngram 
         return re.search(max_sim_string, hay, flags=flags)
+    # exception handling here
     except (StopIteration, RuntimeError):
-        return re.search(needle, hay, flags=flags)
+        return
 
 def get_start_end_index(achievement, rel_string, case_insensitive=False):
     rel_string = rel_string.strip()
     if case_insensitive:
-        matched = fuzzy_match(rel_string, achievement, flags=re.IGNORECASE | re.MULTILINE)
+        matched = fuzzy_match(rel_string, achievement, flags=re.IGNORECASE | re.MULTILINE | re.DOTALL)
     else:
         matched = fuzzy_match(rel_string, achievement)
     if matched is None:
